X-Git-Url: https://git.saurik.com/wxWidgets.git/blobdiff_plain/f01a77c7954ff4b7ee9f74af8df5a16f239d3537..60913641356f364a5efee5966d3a3b0b48c01001:/include/wx/ipcbase.h

diff --git a/include/wx/ipcbase.h b/include/wx/ipcbase.h
index 45c0f44553..ae4bbca0a6 100644
--- a/include/wx/ipcbase.h
+++ b/include/wx/ipcbase.h
@@ -180,10 +180,21 @@ public:
   virtual bool OnDisconnect() { delete this; return true; }
 
 
+  // return true if this is one of the formats used for textual data
+  // transmission
+  static bool IsTextFormat(wxIPCFormat format)
+  {
+      return format == wxIPC_TEXT ||
+             format == wxIPC_UTF8TEXT ||
+             format == wxIPC_UTF16TEXT ||
+             format == wxIPC_UTF32TEXT;
+  }
+
   // converts from the data and format into a wxString automatically
   //
   // this function accepts data in all of wxIPC_TEXT, wxIPC_UNICODETEXT, and
   // wxIPC_UTF8TEXT formats but asserts if the format is anything else
   //
   // notice that the size parameter here contains the total size of the data,
   // including the terminating '\0' or L'\0'
@@ -180,10 +180,21 @@ public:
   //
   // this function accepts data in all of wxIPC_TEXT, wxIPC_UNICODETEXT, and
-  // wxIPC_UTF8TEXT formats but asserts if the format is anything else
+  // wxIPC_UTF8TEXT formats but asserts if the format is anything else (i.e.
+  // such that IsTextFormat(format) doesn't return true)
   //
   // notice that the size parameter here contains the total size of the data,